import logging

def autodetect_framework(script):
    # script : path to the script of which we want to detect the framework

    with open(script,"rb") as file :
        data=file.read().decode("utf8").lower()
    if "torch" in data:
        return "PyTorch"
    elif "tensorflow" in data:
        return "TensorFlow"
    elif "chainer" in data:
        return "Chainer"
    else : 
        return "Estimator"

def check_data_url(url):
    #function that converts the url of a blob data into the storage name and the folder path
    #also checks a few possible url defaults
    if url.split(":")[0]!="https":
        return None, "not an url"
    elif "." in url.split("/")[len(url.split("/"))-1]:
        return None, "not a folder"
    elif "blob.windows.core" not in url:
        return None, "not in a blob. Only blob storage is supported for online data"
    else :
        try :
            fullpath=url.replace("https://","")
            storage_account=fullpath.split("/")[0].split(".")[0]
            storage_path=fullpath.replace(fullpath.split("/")[0],"")
            return storage_account,storage_path
        except:
            return None, "unknown data path error. \"data\" should look like https://mystorage.blob.core.windows.net/myfolder"


def get_dependencies(myscript):
    # lists the needed packages from a given file. does not get second level dependencies
    to_ignore=["time","","__future__","random","__future__","sys","re","collections","distutils","os","urllib","urllib2","gzip","argparse","logging"]
    to_replace={"sklearn":"scikit-learn","torch":"torchvision","pytorch":"torchvision","optparse":"optparse_gui"}
    dependencies=[]
    with open(myscript,"rb") as file :
        data=file.read().decode("utf8").lower()
    if data is None :
        print("failure",data)
        return []
    lines=data.replace("\r","").split("\n")
    for line in lines :
        if ("import " in line) and (line is not None) and ("#" not in line) :
            words=[k.split(".")[0] for k in line.split(" ") if len(k)>1]
            dependencies.append(words[1])
    result=[]
    for dependency in dependencies :
       
        if dependency in to_replace.keys() :
            if not(to_replace[dependency] in result) :
                result.append(to_replace[dependency])
        else :
            if (not (dependency in to_ignore)) and (not(dependency in result)):            
                result.append(dependency)
        
    return result



import os
from pipeline import do_stuff

for root, dirs, files in os.walk("../my_tests/sample_scripts/pytorch", topdown=False):
    for name in files :

        if (".py" in name) :
                try :
                        script=os.path.join(root, name)
                        print("working on ",script)
                        do_stuff({"script":script,"experiment_name":"default","project_folder":None,"framework":None,"cluster_name":"basic","storage_account":None,"storage_key":None,"storage_path":None,"data":None})
                except Exception as err :
                        print(err)


from azureml.core.compute import ComputeTarget, AmlCompute
import time
from azureml.core.runconfig import DataReferenceConfiguration
time0=time.time()
import argparse
import os
from pipeline import do_stuff

def main():
    ap = argparse.ArgumentParser()
    ap.add_argument('--experiment_name','-e',help='name of your AML experiment',default="default")
    ap.add_argument('--script','-s',help='name of the file to train')
    ap.add_argument('--data',help='url of the data folder')
    ap.add_argument("--project_folder", "-p",help='folder where the files will be')
    ap.add_argument('--framework','-f',help="TensorFlow, PyTorch, Chainer, and Python are supported ")
    ap.add_argument('--region','-r',help='Azure region where the compute happens',default="westeurope")
    ap.add_argument("--storage_account","-d",help='account name for location of data (must be blob here)')
    ap.add_argument("--storage_key",help='storage key')
    ap.add_argument("--storage_path",help='container in the storage account where the data is')
    ap.add_argument('--subscription_id',help='id of the subscription on which the service will be provider')
    ap.add_argument('--resource_group','-g',help='id of the resource group on which the service will be provider',default="amlfbp")
    ap.add_argument('--cluster_name','-c',help='name of the cluster on which to work',default="basic")
    ap.add_argument('--workspace_name','-w',help='id of the workspace',default="default")
    ap.add_argument('--vm_size',help='type of VM on which to run the compute',default="STANDARD_D2_V2")
    ap.add_argument('--max_nodes','-n',help='maximum number of nodes allowed on the cluster',default=2)

    args = vars(ap.parse_args())

    import json 
    if os.path.isfile("config.json") :
        if input("found a local config.json, do you want to continue with it? (y/n)")=="y":            
            with open("config.json") as jsondata :
                localargs=json.load(jsondata)

            for key in args.keys():
                if (args[key] is None) and (key in localargs.keys()) :
                    args[key]=localargs[key]
    args = do_stuff(args)
    if args is not None :
        with open("config.json","w") as file :
            print("dumping file",args)
            json.dump(args,file)

if __name__=="__main__" :
    main()